==> opinion_monitor-7.x-1.3.tar.gz: opinion_monitor/opinion_monitor_answer_slider.js <==
jQuery(function(){
  // Set a default value and apply it to all the slider value fields.
  var defaultValue = 0;
  jQuery('.opmon-answer-slider-field').val(defaultValue);

  // Create a jQuery UI slider element for each question.
  jQuery('.opmon-answer-slider').slider({
    min: -1,
    max: 1,
    step: 0.01,
    value: defaultValue,
    slide: function(event, ui) {
      var form = jQuery(jQuery(this).closest('form')),
          sliderValueField = jQuery(jQuery(this).closest('li').find('input[type="hidden"]'));

      // Change some interface text to instruct the user to save their changes.
      contentGroupUnsaved(jQuery(this).closest('.opmon-questions-wrapper'));

      // Update the slider's hidden value field.
      sliderValueField.val(ui.value);
    }
  });

  // Pass these functions an element with an 'opmon-questions-wrapper' class.
  function contentGroupSaved(contentGroupElement, message) {
    if (message == null) {
      message = 'Saved.';
    }
    var formResponse = jQuery(contentGroupElement.find('.opmon-form-response'));
    formResponse.removeClass('opmon-form-response-unsaved');
    formResponse.addClass('opmon-form-response-saved');
    formResponse.html(message);
    var formButton = jQuery(contentGroupElement.find('.opmon-form-submit'));
    formButton.hide();
  }
  function contentGroupUnsaved(contentGroupElement, message) {
    if (message == null) {
      message = 'Click "Save" to save your changes.';
    }
    var formResponse = jQuery(contentGroupElement.find('.opmon-form-response'));
    formResponse.removeClass('opmon-form-response-saved');
    formResponse.addClass('opmon-form-response-unsaved');
    formResponse.html(message);
    var formButton = jQuery(contentGroupElement.find('.opmon-form-submit'));
    formButton.show();
  }

  // Initialise the sliders.
  var sliderFields = jQuery('.opmon-answer-slider-field');
  jQuery.each(sliderFields, function(index, element){
    // See if there's a value already defined for this slider.
    var elementId = jQuery(element).attr('id'),
        elementIdParts = elementId.split('-');
    if(opmonValues['c_' + elementIdParts[4]] && opmonValues['c_' + elementIdParts[4]]['q_' + elementIdParts[5]]) {
      var sliderValue = opmonValues['c_' + elementIdParts[4]]['q_' + elementIdParts[5]];
      jQuery(this).val(sliderValue);
      jQuery(this).parent().find('.opmon-answer-slider').slider('option', 'value', sliderValue);

      contentGroupSaved(jQuery(this).closest('.opmon-questions-wrapper'));
    }
    else {
      contentGroupUnsaved(jQuery(this).closest('.opmon-questions-wrapper'), '');
    }
  });

  // Handle a slider form submission.
  jQuery('.opmon-form-submit').click(function(){
    var form = jQuery(jQuery(this).closest('form')),
        answers = form.find('input[type="hidden"]'),
        data = '';

    // Collate the answers for this content's questions.
    jQuery.each(answers, function(index, answer){
      data = data + (data != '' ? '&' : '') + jQuery(answer).attr('id') + '=' + jQuery(answer).val();
    });

    // Submit the answers to the handler.
    jQuery.ajax({
      type: 'POST',
      url: Drupal.settings.basePath + 'opmon/submit',
      data: data,
      dataType: 'json',
      success: function(response){
        contentGroupSaved(form.closest('.opmon-questions-wrapper'));
      },
      error: function(){
        contentGroupUnsaved(form.closest('.opmon-questions-wrapper'), 'Couldn\'t save - please try again.');
      }
    });
  });

  // Initialise the user metrics form fields.
  var metricsFields = find('#opinion-monitor-prepare-frontend-metrics-form select[id^="opmon-metrics-input-"]');
  jQuery(metricsFields).change(function(event){
    // Change some interface text to instruct the user to save their changes.
    contentGroupUnsaved(jQuery(event.target).closest('.opmon-questions-wrapper'));
  });

  // Handle a user metrics form submission.
  jQuery('#opmon-metrics-submit').click(function(){
    var form = jQuery('#opinion-monitor-prepare-frontend-metrics-form'),
        answers = form.find('select[id^="opmon-metrics-input-"]'),
        data = '';
    // Collate the answers for this content's questions.
    jQuery.each(answers, function(index, answer){
      data = data + (data != '' ? '&' : '') + jQuery(answer).attr('id') + '=' + jQuery(answer).val();
    });
    // Submit the answers to the handler.
    jQuery.ajax({
      type: 'POST',
      url: Drupal.settings.basePath + 'opmon/submit_metrics',
      data: data,
      dataType: 'json',
      success: function(response){
        contentGroupSaved(form.closest('.opmon-questions-wrapper'));
      },
      error: function(){
        contentGroupUnsaved(form.closest('.opmon-questions-wrapper'), 'Couldn\'t save - please try again.');
      }
    });
    // Abort the standard form submission.
    return false;
  });

  // Use jQuery to set the tabindex of the jQuery UI sliders, and all the other form elements, to the order they appear in the HTML.
  var tabIndexCounter = 0;
  jQuery.each(
    jQuery('a.ui-slider-handle, input.opmon-form-submit, input#opmon-metrics-submit, input#opmon-results-compare, select[id^="opmon-"]'),
    function(index, metric) {
      jQuery(metric).attr('tabindex', tabIndexCounter++);
    }
  );
});

==> opinion_monitor-7.x-1.8.tar.gz: opinion_monitor/opinion_monitor_answer_slider.js <==
jQuery(function(){
  // Set a default value and apply it to all the slider value fields.
  var defaultValue = 0;
  jQuery('.opmon-answer-slider-field').val(defaultValue);

  // Create a jQuery UI slider element for each question.
  jQuery('.opmon-answer-slider').slider({
    min: -1,
    max: 1,
    step: 0.01,
    value: defaultValue,
    slide: function(event, ui) {
      var form = jQuery(jQuery(this).closest('form')),
          sliderValueField = jQuery(jQuery(this).closest('li').find('input[type="hidden"]'));

      // Change some interface text to instruct the user to save their changes.
      contentGroupUnsaved(jQuery(this).closest('.opmon-questions-wrapper'));

      // Update the slider's hidden value field.
      sliderValueField.val(ui.value);
    }
  });

  // Pass these functions an element with an 'opmon-questions-wrapper' class.
  function contentGroupSaved(contentGroupElement, message) {
    if (message == null) {
      message = 'Saved.';
    }
    var formResponse = jQuery(contentGroupElement.find('.opmon-form-response'));
    formResponse.removeClass('opmon-form-response-unsaved');
    formResponse.addClass('opmon-form-response-saved');
    formResponse.html(message);
    var formButton = jQuery(contentGroupElement.find('.opmon-form-submit'));
    formButton.hide();
  }
  function contentGroupUnsaved(contentGroupElement, message) {
    if (message == null) {
      message = 'Click "Save" to save your changes.';
    }
    var formResponse = jQuery(contentGroupElement.find('.opmon-form-response'));
    formResponse.removeClass('opmon-form-response-saved');
    formResponse.addClass('opmon-form-response-unsaved');
    formResponse.html(message);
    var formButton = jQuery(contentGroupElement.find('.opmon-form-submit'));
    formButton.show();
  }

  // Initialise the sliders.
  var sliderFields = jQuery('.opmon-answer-slider-field');
  jQuery.each(sliderFields, function(index, element){
    // See if there's a value already defined for this slider.
    var elementId = jQuery(element).attr('id'),
        elementIdParts = elementId.split('-');
    if(opmonValues['c_' + elementIdParts[4]] && opmonValues['c_' + elementIdParts[4]]['q_' + elementIdParts[5]]) {
      var sliderValue = opmonValues['c_' + elementIdParts[4]]['q_' + elementIdParts[5]];
      jQuery(this).val(sliderValue);
      jQuery(this).parent().find('.opmon-answer-slider').slider('option', 'value', sliderValue);

      contentGroupSaved(jQuery(this).closest('.opmon-questions-wrapper'));
    }
    else {
      contentGroupUnsaved(jQuery(this).closest('.opmon-questions-wrapper'), '');
    }
  });

  // Handle a slider form submission.
  jQuery('.opmon-form-submit').click(function(){
    var form = jQuery(jQuery(this).closest('form')),
        answers = form.find('input[type="hidden"]'),
        data = '';

    // Collate the answers for this content's questions.
    jQuery.each(answers, function(index, answer){
      data = data + (data != '' ? '&' : '') + jQuery(answer).attr('id') + '=' + jQuery(answer).val();
    });

    // Submit the answers to the handler.
    jQuery.ajax({
      type: 'POST',
      url: Drupal.settings.basePath + 'opmon/submit',
      data: data,
      dataType: 'json',
      success: function(response){
        contentGroupSaved(form.closest('.opmon-questions-wrapper'));
      },
      error: function(){
        contentGroupUnsaved(form.closest('.opmon-questions-wrapper'), 'Couldn\'t save - please try again.');
      }
    });
  });

  // Initialise the user metrics form fields.
  jQuery('#opinion-monitor-prepare-frontend-metrics-form select[id^="opmon-metrics-input-"]').change(function(event){
    // Change some interface text to instruct the user to save their changes.
    contentGroupUnsaved(jQuery(event.target).closest('.opmon-questions-wrapper'));
  });

  // Handle a user metrics form submission.
  jQuery('#opmon-metrics-submit').click(function(){
    var form = jQuery('#opinion-monitor-prepare-frontend-metrics-form'),
        answers = form.find('select[id^="opmon-metrics-input-"]'),
        data = '';
    // Collate the answers for this content's questions.
    jQuery.each(answers, function(index, answer){
      data = data + (data != '' ? '&' : '') + jQuery(answer).attr('id') + '=' + jQuery(answer).val();
    });
    // Submit the answers to the handler.
    jQuery.ajax({
      type: 'POST',
      url: Drupal.settings.basePath + 'opmon/submit_metrics',
      data: data,
      dataType: 'json',
      success: function(response){
        contentGroupSaved(form.closest('.opmon-questions-wrapper'));
      },
      error: function(){
        contentGroupUnsaved(form.closest('.opmon-questions-wrapper'), 'Couldn\'t save - please try again.');
      }
    });
    // Abort the standard form submission.
    return false;
  });

  // Use jQuery to set the tabindex of the jQuery UI sliders, and all the other form elements, to the order they appear in the HTML.
  var tabIndexCounter = 0;
  jQuery.each(
    jQuery('a.ui-slider-handle, input.opmon-form-submit, input#opmon-metrics-submit, input#opmon-results-compare, select[id^="opmon-"]'),
    function(index, metric) {
      jQuery(metric).attr('tabindex', tabIndexCounter++);
    }
  );
});
